#!/usr/bin/python3

import pytest
import yaml
from influxdb import InfluxDBClient


@pytest.fixture(scope="module", params=[{'config': {'rspec': 'test/streaming-sim/rspec.yml'}}])
def streaming_sim_config(request):
    """
    Reads the service configuration deployed for the streaming simulation test.

    :param request: access the parameters of the fixture
    :return: the python object representing the read YAML file
    """

    with open(request.param['config']['rspec'], 'r') as stream:
        data_loaded = yaml.load(stream)
    return data_loaded


@pytest.fixture(params=[{'database': 'CLMCMetrics'}], scope='module')
def get_db_client(streaming_sim_config, request):
    """
    Creates an Influx DB client for the CLMC metrics database

    :param streaming_sim_config: the fixture returning the yaml configuration
    :param request: access the parameters of the fixture
    :return: the created Influx DB client
    """

    return InfluxDBClient(host=streaming_sim_config['hosts'][0]['ip_address'], port=8086, database=request.param['database'], timeout=10)
